==> lms-1.1.2b.tar.gz: lms/lib/accesstable.php <==
<?php

/*
 * LMS version 1.1.2b
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: accesstable.php,v 1.12 2003/08/24 13:12:54 lukasz Exp $
 */

// lista moduw ktre zawsze s dostpne dla kadego

$access[allow] = "^(welcome|copyrights|logout|chpasswd)$";

$access[table][0][name]		= "peen dostp";
$access[table][0][allow_reg]	= "^.*$";

$access[table][1][name]		= "odczyt wszystkich danych";
$access[table][1][allow_reg]	= "^((admin|balance|db|net|node|tariff|user)(list|list(debt|disc)|info|view|debt|search|balance)|print)$";

$access[table][2][name]		= "wczanie i odczanie komputerw";
$access[table][2][allow_reg]	= "^nodeset$";

$access[table][3][name]		= "manipulacja finansami";
$access[table][3][allow_reg]	= "^(balancenew|balanceadd|userbalanceok)$";

$access[table][4][name]         = "przeadowywanie konfiguracji";
$access[table][4][allow_reg]    = "^reload$";

$access[table][5][name]		= "manipulacja kontami uytkownikw";
$access[table][5][allow_reg]	= "^user(add|edit|del)$";

$access[table][6][name]		= "manipulacja danymi komputerw";
$access[table][6][allow_reg]	= "^(node(add|scan|del|edit|set)|choose(mac|ip))$";

$access[table][253][name]	= "brak dostpu do modyfikacji i zakadania nowych kont administratorw";
$access[table][253][deny_reg]	= "^(admin(add|del|edit|passwd))$";

$access[table][255][name]	= "brak dostpu";
$access[table][255][deny_reg]	= "^.*$";

/*
 * $Log: accesstable.php,v $
 * Revision 1.12  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.11  2003/08/18 16:57:00  lukasz
 * - more cvs tags :>
 *
 */

?>

==> lms-1.1.5.tar.gz: lms/lib/accesstable.php <==
<?php

/*
 * LMS version 1.1.5 Amaonet
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: accesstable.php,v 1.14 2003/09/11 17:29:30 lexx Exp $
 */

// lista moduw ktre zawsze s dostpne dla kadego

$access[allow] = "^(welcome|copyrights|logout|chpasswd)$";

$access[table][0][name]		= "peen dostp";
$access[table][0][allow_reg]	= "^.*$";

$access[table][1][name]		= "odczyt wszystkich danych";
$access[table][1][allow_reg]	= "^((admin|balance|db|net|node|tariff|user)(list|list(debt|disc)|info|view|debt|search|balance)|print)$";

$access[table][2][name]		= "wczanie i odczanie komputerw";
$access[table][2][allow_reg]	= "^nodeset$";

$access[table][3][name]		= "manipulacja finansami";
$access[table][3][allow_reg]	= "^(balancenew|balanceadd|userbalanceok|faktura)$";

$access[table][4][name]         = "przeadowywanie konfiguracji";
$access[table][4][allow_reg]    = "^reload$";

$access[table][5][name]		= "manipulacja kontami uytkownikw";
$access[table][5][allow_reg]	= "^user(add|edit|del)$";

$access[table][6][name]		= "manipulacja danymi komputerw";
$access[table][6][allow_reg]	= "^(node(add|scan|del|edit|set)|choose(mac|ip))$";

$access[table][7][name]         = "dostp do statystyk";
$access[table][7][allow_reg]    = "^traffic$";

$access[table][253][name]	= "brak dostpu do modyfikacji i zakadania nowych kont administratorw";
$access[table][253][deny_reg]	= "^(admin(add|del|edit|passwd))$";

$access[table][255][name]	= "brak dostpu";
$access[table][255][deny_reg]	= "^.*$";

/*
 * $Log: accesstable.php,v $
 * Revision 1.14  2003/09/11 17:29:30  lexx
 * - taffic
 *
 * Revision 1.13  2003/09/10 13:38:34  lexx
 * - faktury
 *
 * Revision 1.12  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.11  2003/08/18 16:57:00  lukasz
 * - more cvs tags :>
 *
 */

?>
